part of 'vehicles_on_the_property.dart';

/// [VehicleUpdateScreen] is a StatefulWidget that displays a form to update a vehicle.

// ignore: must_be_immutable
class VehicleUpdateScreen extends StatefulWidget {
  VehicleUpdateScreen(this.model, {super.key});
  late VehicleModel model;

  @override
  State<VehicleUpdateScreen> createState() => _VehicleUpdateScreenState();
}

class _VehicleUpdateScreenState extends State<VehicleUpdateScreen> {
  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        mainAxisSize: MainAxisSize.max,
        children: [
          _buildHeader(context),
          buildBody(context),
        ],
      ),
    );
  }

  Form buildBody(BuildContext context) {
    return Form(
      key: widget.model.updateFormKey,
      autovalidateMode: AutovalidateMode.onUserInteraction,
      child: Column(
        mainAxisSize: MainAxisSize.max,
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          _buildCustomInput(
            context: context,
            controller: widget.model.textFieldControllerLicensePlate!,
            validator: widget.model.textControllerLicensePlateValidator,
            focusNode: widget.model.textFieldFocusLicensePlate!,
            labelText: FFLocalizations.of(context)
                .getVariableText(ptText: 'Placa', enText: 'License Plate'),
            hintText: FFLocalizations.of(context)
                .getVariableText(ptText: 'Placa', enText: 'License Plate'),
            suffixIcon: Symbols.format_color_text,
          ),
          _buildCustomInput(
            context: context,
            controller: widget.model.textFieldControllerModel!,
            validator: widget.model.textControllerModelValidator,
            focusNode: widget.model.textFieldFocusModel!,
            labelText: FFLocalizations.of(context)
                .getVariableText(ptText: 'Modelo', enText: 'Model'),
            hintText: FFLocalizations.of(context).getVariableText(
                ptText: 'Ex: Voyage, Ford', enText: 'e.g. Voyage, Ford'),
            suffixIcon: Symbols.car_repair,
          ),
          _buildCustomInput(
            context: context,
            controller: widget.model.textFieldControllerColor!,
            validator: widget.model.textControllerColorValidator,
            focusNode: widget.model.textFieldFocusColor!,
            labelText: FFLocalizations.of(context)
                .getVariableText(ptText: 'Cor', enText: 'Color'),
            hintText: FFLocalizations.of(context).getVariableText(
                ptText: 'Ex: Preto, Amarelo, Branco',
                enText: 'e.g. Black, Yellow, White'),
            suffixIcon: Symbols.palette,
          ),
          _buildSubmitButton(context),
        ],
      ),
    );
  }

  Widget _buildHeader(BuildContext context) {
    return Align(
      alignment: const AlignmentDirectional(-1.0, 0.0),
      child: Padding(
        padding: const EdgeInsetsDirectional.fromSTEB(24.0, 20, 0.0, 15),
        child: Text(
          FFLocalizations.of(context).getVariableText(
            ptText:
                'Preencha o formulário de alteração com os dados do seu veículo',
            enText: 'Fill out the update form with your vehicle data',
          ),
          textAlign: TextAlign.start,
          style: FlutterFlowTheme.of(context).bodyMedium.override(
                fontFamily: FlutterFlowTheme.of(context).bodyMediumFamily,
                letterSpacing: 0.0,
                useGoogleFonts: GoogleFonts.asMap()
                    .containsKey(FlutterFlowTheme.of(context).bodyMediumFamily),
              ),
        ),
      ),
    );
  }

  Widget _buildCustomInput({
    required BuildContext context,
    required TextEditingController controller,
    required String? Function(BuildContext, String?) validator,
    required FocusNode focusNode,
    required String labelText,
    required String hintText,
    required IconData suffixIcon,
  }) {
    return CustomInputUtil(
      controller: controller,
      validator: (value) => validator(context, value),
      focusNode: focusNode,
      labelText: labelText,
      hintText: hintText,
      suffixIcon: suffixIcon,
      haveMaxLength: true,
      onChanged: (value) => setState(() {}),
    );
  }

  Widget _buildSubmitButton(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.fromLTRB(70, 20, 70, 30),
      child: SubmitButtonUtil(
        labelText: FFLocalizations.of(context)
            .getVariableText(ptText: 'Salvar', enText: 'Save'),
        onPressed: widget.model.isFormValid(context, widget.model.updateFormKey)
            ? () => widget.model.updateVehicle()
            : null,
      ),
    );
  }
}
